# 📝 pencil_pusher
A Github Action that creates and publishes source documentation to the repository's wiki. THIS IS NOT A DOCUMENTATION GENERATION TOOL. This tool is designed to take pre-generated documentation and publish it to a the source repository's github wiki page. This removes the need to host a webpage for documentation and allows for an easy way to include documentation generation in your CI/CD pipeline. To get started using this action in your repository check out the **[General Usage](https://github.com/stephend017/pencil-pusher/wiki/General-Usage)** page of our wiki. 

# Tech Stack
- docker
- python
- [pydoc-markdown](https://pydoc-markdown.readthedocs.io/en/latest/)

> this project uses [`snake-charmer`](https://github.com/stephend017/snake-charmer) for automatic releases
